<?php

class DispletRetsIdxLoadController extends DispletRetsIdxPlugin {
	public static function enqueue() {
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		self::enqueue_css( 'displet-rets-idx-styles.css' );
		self::enqueue_google_maps_js();
		self::enqueue_js( 'displet-rets-idx-scripts.js', array( 'jquery', 'jquery-ui-core', 'jquery-ui-datepicker', 'displetretsidx-google-maps-geocoder' ) );
		self::enqueue_js( 'modernizr.placeholder.min.js', array( 'jquery' ) );
		if ( !empty( self::$_options['board_translations'] ) && self::$_options['board_translations'] != 'none' ) {
			self::enqueue_js( 'displet-listing-translations-scripts.js', array( 'jquery' ) );
			self::enqueue_js( 'displet-listing-translations-variables-' . self::$_options['board_translations'] . '.js', array( 'jquery' ) );
		}
		wp_enqueue_style(
			'displetretsidx-font-awesome',
			trailingslashit( self::$_urls['includes'] ) . 'font-awesome-4.1.0/css/font-awesome.min.css',
			false,
			self::$_version
		);
	}

	public static function enqueue_admin() {
		self::enqueue_css( 'displet-rets-idx-admin-styles.css' );
		self::enqueue_google_maps_js();
		self::enqueue_js( 'displet-rets-idx-admin-scripts.js', array( 'jquery', 'jquery-ui-core', 'jquery-ui-datepicker', 'jquery-ui-dialog', 'jquery-ui-tabs', 'jquery-ui-sortable', 'jquery-ui-draggable', 'jquery-ui-droppable', 'admin-widgets' ) );
		wp_enqueue_style( 'wp-pointer' );
		wp_enqueue_script( 'wp-pointer' );
		wp_enqueue_media();
	}

	public static function enqueue_css( $filename ) {
		$custom_template_uri = self::get_custom_template_uri( $filename );
		if ( !empty( $custom_template_uri ) ) {
			$stylesheet_url = $custom_template_uri;
		}
		else{
			$stylesheet_url = plugins_url( self::$_slug . '/includes/css/' . $filename );
		}
		$slug = basename( $filename, '.css' );
		wp_enqueue_style( $slug, $stylesheet_url, false, self::$_version );
	}

	private static function enqueue_google_maps_js() {
		wp_enqueue_script(
			'displetretsidx-google-maps-geocoder',
			'http://maps.googleapis.com/maps/api/js?libraries=drawing,geometry&sensor=false',
			false,
			self::$_version
		);
	}

	public static function enqueu_intercom_io_js_for_agent_and_search_users() {
		if ( is_user_logged_in() && current_user_can( 'displet_view_leads' ) ) {
			wp_enqueue_script(
				'displetretsidx_intercom_io_script',
				trailingslashit( self::$_urls['js'] ) . 'intercom-io-script.js',
				false,
				self::$_version
			);
			$user = wp_get_current_user();
			$intercom_vars = array(
				'name' => $user->display_name,
				'email' => $user->user_email,
				'created_at' => current_time( 'timestamp' ),
				'app_id' => 'lb5nppo2',
				'wp_version' => get_bloginfo( 'version' ),
				'domain' => home_url(),
				'user_hash' => hash_hmac('sha256', $user->user_email, 'k3vZZS7gjJ1p3DIZvbwvC303_TXqLSYWlFwhhS43'),
			);
			$user_leads = DispletRetsIdxUsersController::get_re_search_users_count( $user->ID );
			if ( !empty( $user_leads ) ) {
				$intercom_vars['user_leads'] = $user_leads;
			}
			wp_localize_script( 'displetretsidx_intercom_io_script', 'intercomSettings', $intercom_vars );
		}
	}

	public static function enqueue_js( $filename, $dependencies = array() ) {
		$script_url = plugins_url( self::$_slug . '/includes/js/' . $filename );
		$slug = basename( $filename, '.js' );
		wp_enqueue_script( $slug, $script_url, $dependencies, self::$_version );
	}

	public static function get_custom_template_uri( $filename ) {
		if ( empty( self::$_options['disable_custom_templates'] ) ) {
			$theme_dir = get_stylesheet_directory();
			if ( file_exists( $theme_dir . '/' . $filename ) ) {
				$theme_url = get_stylesheet_directory_uri();
				return $theme_url . '/' . $filename;
			}
			else if ( file_exists( ABSPATH . 'wp-content/plugins/displet-pro-custom/' . $filename ) && is_plugin_active( 'displet-pro-custom/displet-pro-custom.php' ) ) {
				return plugins_url( 'displet-pro-custom/' . $filename );
			}
		}
		return false;
	}

	public static function include_version() {
		echo '<!-- Displet RETS/IDX v. ' . self::$_version . ' -->';
	}
}

?>